@@ -400,6 +400,7 @@ def get_uorf(args):
     uorf_record = []
     index = 0
     mRNA_str = mRNA_type(args.style) 
+    error_count = 0
     # loop all transcripts in genome
     if not args.transcript:
         for t in tqdm(db.features_of_type(mRNA_str, order_by='start'), \
@@ -429,6 +430,17 @@ def get_uorf(args):
                 sc_seq = stop_codon_seq(db, t, args.genome)
                 cds = add_stop_codon(cds, t.strand, sc_seq)
             cds = Seq(cds)
+            ## 需要确定exon和mRNA的位置是否一致，不一致以mRNA为准
+            # mt from utr5/3 and cds
+            mt_from_utr_cds = ''
+            for e in db.children(t, featuretype=['five_prime_UTR','CDS', 'three_prime_UTR'], order_by='start'):
+                mt_from_utr_cds += e.sequence(args.genome, use_strand=False)
+            mt_from_utr_cds = Seq(mt_from_utr_cds)
+            if t.strand == '-':
+                mt_from_utr_cds = mt_from_utr_cds.reverse_complement()
+            if mt != mt_from_utr_cds:
+                mt = mt_from_utr_cds
+                error_count += 1
             if t.strand == '-':
                 cds = cds.reverse_complement()
             # procedure-oriented
@@ -517,6 +529,17 @@ def get_uorf(args):
                     sc_seq = stop_codon_seq(db, t, args.genome)
                     cds = add_stop_codon(cds, t.strand, sc_seq)
                 cds = Seq(cds)
+                ## 需要确定exon和mRNA的位置是否一致，不一致以mRNA为准
+                # mt from utr5/3 and cds
+                mt_from_utr_cds = ''
+                for e in db.children(t, featuretype=['five_prime_UTR','CDS', 'three_prime_UTR'], order_by='start'):
+                    mt_from_utr_cds += e.sequence(args.genome, use_strand=False)
+                mt_from_utr_cds = Seq(mt_from_utr_cds)
+                if t.strand == '-':
+                    mt_from_utr_cds = mt_from_utr_cds.reverse_complement()
+                if mt != mt_from_utr_cds:
+                    mt = mt_from_utr_cds
+                    error_count += 1
                 cds_len = len(cds)
                 if t.strand == '-':
                     cds = cds.reverse_complement()
