@@ -291,9 +291,9 @@ parser_uORF.add_argument('-t', '--output_format', choices=['csv','fasta','gff'],
                         help='output format ')
 parser_uORF.add_argument('-o', '--output', type=str, 
                          help='output file path')
-parser_uORF.add_argument('-m', '--schematic_without_intron', type=str,
+parser_uORF.add_argument('-m', '--schematic_without_intron', action='store_false',default='False',
                          help='schematic figure file for uORF, CDS and transcript without intron')
-parser_uORF.add_argument('-n', '--schematic_with_intron', type=str,
+parser_uORF.add_argument('-n', '--schematic_with_intron', action='store_false',default='False',
                          help='schematic figure file for uORF, CDS and transcript with intron')
 parser_uORF.add_argument('-s', '--style', choices=['GFF','GTF'], 
                          help = 'GTF database or GFF database')
